@@ -1,4 +1,5 @@
 from .asserts import *
+from .context import *
 from .runner import start
 from .annotations import *
 from .classes.mocking import *
@@ -10,5 +11,5 @@ from .classes.listeners.file_logger import DefaultFileListener
 __all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'Double', 'DefaultFileListener', 'DATA_FILE', 'CONTAINER',
            'equals', 'is_none', 'not_none', 'waiting_exception', 'test_fail', 'test_brake', 'no_exception_expected',
            'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true', 'mock_builtins', 'mock',
-           'is_zero', 'is_positive', 'is_negative',
+           'is_zero', 'is_positive', 'is_negative', 'mock_open', 'Stub',
            'test', 'before', 'after', 'before_group', 'after_group', 'before_suite', 'after_suite', 'data']
