@@ -10,7 +10,7 @@ from .exceptions import *
 from .classes.basic_test import Test
 from .classes.data_file import DataFile
 from .classes.basic_suite import TestSuite
-from .helpers.others import is_file_exists
+from .helpers.others import is_file_exists, fake
 
 
 def test(*args, enabled: bool = True, name: str = None, description: str = None, data_provider: str = None,
@@ -40,10 +40,10 @@ def test(*args, enabled: bool = True, name: str = None, description: str = None,
     Due to a possible memory leak, it should be used only when there is a special need.
     :param only_if: accepts a function that will be called before the test starts and the test will only be launched if
     it returns True. Should be taken to filter tests, for instance in relation to the operating system used.
-    :return: _fake
+    :return: fake
     """
     if not enabled:
-        return _fake
+        return fake
 
     def real_decorator(func: Callable[[], None]):
         if not data_provider:
@@ -74,14 +74,14 @@ def test(*args, enabled: bool = True, name: str = None, description: str = None,
             if data_provider:
                 test_object.provider = data_provider
             TestSuite.get_instance().get_or_create(group).add_test(test_object)
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
     return real_decorator
 
 
-def data(*args, enabled: bool = True, name: str = None):
+def data(*args, enabled: bool = True, name: str = None, cached: bool = False):
     """
     The annotation that marks a data provider, that is, a function that supplies data to a test. Such a function should
     return Iterable or Sequence, otherwise will be an error. It is not possible at compile time to determine if the
@@ -92,12 +92,15 @@ def data(*args, enabled: bool = True, name: str = None):
     its other settings are ignored
     :param name: is the name, if not specified, then takes the name of the function. By this name, tests are searched by
     the provider, therefore only unique names are allowed. Duplicate name throws DuplicateNameException
-    :return: __fake
+    :param cached: flag to save all provider data in memory and use it on second use. Can be useful only when provider
+    used more than once in test-suite and you do not want to get data again from some source like filesystem or db.
+    WARNING! Cache use memory, so it can take a lot of it for big data volumes.
+    :return: fake
     :raises: DuplicateNameException if provider with such name is already exists
     :raises: WrongAnnotationPlacement if @data annotation used on function without return or yield statements
     """
     if not enabled:
-        return _fake
+        return fake
 
     def real_decorator(func: Callable[[None], Iterable]):
         __check_is_function_without_args(func, 'data')
@@ -108,7 +111,10 @@ def data(*args, enabled: bool = True, name: str = None):
         if name_ in providers:
             raise DuplicateNameException(f'Provider with name "{name_}" already exists! Only unique names allowed!')
         providers[name_] = func
-        return _fake
+        nonlocal cached
+        if cached:
+            TestSuite.get_instance().cached.append(name_)
+        return fake
 
     if args:
         return real_decorator(args[0])
@@ -121,14 +127,14 @@ def before(*args, group_name: str = None):
     :param group_name: the name of the group before which test the function will be executed. If no group name is
     specified, a group is automatically created with the module name. A function does not have to be in the same module
     as the tests.
-    :return: __fake
+    :return: fake
     """
 
     def real_decorator(func: Callable[[], None]):
         __check_is_function_without_args(func, 'before')
         group = group_name if group_name else func.__module__
         TestSuite.get_instance().get_or_create(group).add_before_test(func)
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
@@ -142,14 +148,14 @@ def after(*args, group_name: str = None):
     :param group_name: the name of the group after each test of which the function will be executed. If the group name
     is not specified, a group with the module name is automatically created. A function does not have to be in the same
     module as the tests.
-    :return: __fake
+    :return: fake
     """
 
     def real_decorator(func: Callable[[], None]):
         __check_is_function_without_args(func, 'after')
         group = group_name if group_name else func.__module__
         TestSuite.get_instance().get_or_create(group).add_after_test(func)
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
@@ -162,14 +168,14 @@ def before_group(*args, name: str = None):
     all module/group tests are run.
     :param name: is the name of the module or group, before which tests the function will be executed once. If no name
     is specified, then the name of the current module where the annotation is used is taken.
-    :return: __fake
+    :return: fake
     """
 
     def real_decorator(func: Callable[[], None]):
         __check_is_function_without_args(func, 'before_module')
         group = name if name else func.__module__
         TestSuite.get_instance().get_or_create(group).add_before(func)
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
@@ -187,7 +193,7 @@ def after_group(*args, name: str = None, always_run: bool = False):
     :param args: are parameters in which a function may come if the method is marked simply by @after_module
     :param always_run: is the function start flag, regardless of the result of the preliminary functions. If True, it
     will be launched anyway
-    :return: __fake
+    :return: fake
     """
 
     def real_decorator(func: Callable[[], None]):
@@ -196,7 +202,7 @@ def after_group(*args, name: str = None, always_run: bool = False):
         TestSuite.get_instance().get_or_create(group).add_after(func)
         if always_run:
             TestSuite.get_instance().get_or_create(group).always_run_after = True
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
@@ -223,7 +229,7 @@ def after_suite(*args, always_run: bool = False):
     :param args: are parameters in which a function may come if the method is marked simply @after_suite
     :param always_run: is the function start flag, regardless of the result of the preliminary functions. If True, it
     will be launched anyway
-    :return: __fake
+    :return: fake
     """
 
     def real_decorator(func: Callable[[], None]):
@@ -231,22 +237,13 @@ def after_suite(*args, always_run: bool = False):
         TestSuite.get_instance().add_after(func)
         if always_run:
             TestSuite.always_run_after = True
-        return _fake
+        return fake
 
     if args:
         return real_decorator(args[0])
     return real_decorator
 
 
-def _fake(*args):
-    """
-    Stub function that does nothing
-    :param args:
-    :return: None
-    """
-    pass
-
-
 def _has_yield_or_return(function: Callable) -> bool:
     code = getsource(function)
     return ' return ' in code or ' yield ' in code
@@ -295,12 +292,14 @@ def __check_is_function_for_provider(func: Callable[[Any], None]):
                                        f"has more than 1 argument!")
 
 
-def DATA_FILE(file_path: str, provider_name: str = None, encoding: str = 'UTF-8', map_function: Callable = None):
+def DATA_FILE(file_path: str, provider_name: str = None, cached: bool = False, encoding: str = 'UTF-8',
+              map_function: Callable = None):
     """
     Function to use text file as data provider for test. Reads file lazily, do not get it to memory.
     The function name explicitly stays uppercase for user to pay attention to it.
     User must call it at the global module namespace, but not at fixtures or in tests!
     :param provider_name: name of the data-provider for use it in test, if not specified the file_path be used as name
+    :param cached: flag to cache values for using it more than once
     :param file_path: file name or path-to-file with name, it can be full or relative path, but it must be "visible"
     (accessible from module, where it is declared)
     :param encoding: encoding of the text file (default UTF-8)
@@ -322,7 +321,7 @@ def DATA_FILE(file_path: str, provider_name: str = None, encoding: str = 'UTF-8'
         real_path = path.join(first_path, file_path)
         if not is_file_exists(real_path):
             raise ValueError(f'Cant find file! Is file "{real_path}" exists?')
-        data(name=provider_name)(wrapper)
+        data(name=provider_name, cached=cached)(wrapper)
     finally:
         del frame
 
