@@ -1,7 +1,8 @@
+from .stub import Stub
 from .calls import Call
 from .doubles import Spy
 from .doubles import Double
 from .interfaces import Observer
 from .wrapper import AttributeWrapper
 
-__all__ = ('Spy', 'Call', 'Double', 'Observer', 'AttributeWrapper')
+__all__ = ('Spy', 'Call', 'Stub', 'Double', 'Observer', 'AttributeWrapper')
